API Reference
=============

This page documents the core API of pypecdp.

Browser
-------

.. autoclass:: pypecdp.browser.Browser
   :members:
   :undoc-members:
   :show-inheritance:

Tab
---

.. autoclass:: pypecdp.tab.Tab
   :members:
   :undoc-members:
   :show-inheritance:

Elem
----

.. autoclass:: pypecdp.elem.Elem
   :members:
   :undoc-members:
   :show-inheritance:

Config
------

.. autoclass:: pypecdp.config.Config
   :members:
   :undoc-members:
   :show-inheritance:

CookieJar
---------

.. autoclass:: pypecdp.util.CookieJar
   :members:
   :undoc-members:
   :show-inheritance:
